/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.apio.architect.operation;

import aQute.bnd.annotation.ProviderType;

import com.liferay.apio.architect.form.Form;

import java.util.Optional;

/**
 * Represents a resource's operation.
 *
 * @author Alejandro Hernández
 */
@ProviderType
public interface Operation {

	/**
	 * Returns this operation's expected form, if present; returns {@code
	 * Optional#empty()} otherwise.
	 *
	 * @return the operation's expected form, if present; {@code
	 *         Optional#empty()} otherwise
	 */
	public Optional<Form> getFormOptional();

	/**
	 * Returns the operation's method.
	 *
	 * @return the operation's method
	 * @review
	 */
	public HTTPMethod getHttpMethod();

	/**
	 * Returns the operation's name.
	 *
	 * @return the operation's name
	 * @review
	 */
	public String getName();

	/**
	 * Returns the operation's uri.
	 *
	 * @return the operation's uri
	 * @review
	 */
	public Optional<String> getURIOptional();

	/**
	 * Return {@code true} if this is a collection's operation
	 *
	 * @return {@code true} if this is a collection's operation
	 * @review
	 */
	public boolean isCollection();

}