/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.apio.architect.pagination;

import aQute.bnd.annotation.ConsumerType;

import java.util.Collection;

/**
 * Provides the information needed by Apio Architect to construct a valid {@link
 * Page}.
 *
 * @author Alejandro Hernández
 * @param  <T> the model's type
 */
@ConsumerType
public class PageItems<T> {

	public PageItems(Collection<T> items, int totalCount) {
		_items = items;
		_totalCount = totalCount;
	}

	/**
	 * Returns the page's items.
	 *
	 * @return the page's items
	 */
	public Collection<T> getItems() {
		return _items;
	}

	/**
	 * Returns the total number of elements in the collection.
	 *
	 * @return the total number of elements in the collection
	 */
	public int getTotalCount() {
		return _totalCount;
	}

	private final Collection<T> _items;
	private final int _totalCount;

}