/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.apio.architect.related;

import aQute.bnd.annotation.ProviderType;

import com.liferay.apio.architect.identifier.Identifier;

import java.util.function.Function;

/**
 * Represents the relation between two resources.
 *
 * @author Alejandro Hernández
 * @author Carlos Sierra Andrés
 * @author Jorge Ferrer
 * @param  <T> the model's type
 * @param  <S> the model identifier's type (e.g., {@code Long}, {@code String},
 *         etc.)
 */
@ProviderType
public interface RelatedModel<T, S> {

	/**
	 * Returns the related resource identifier's class.
	 *
	 * @return the related resource identifier's class
	 */
	public Class<? extends Identifier<S>> getIdentifierClass();

	/**
	 * Returns the function you can use to retrieve the related resource's
	 * identifier.
	 *
	 * @return     the function that calculates the related resource's
	 *             identifier
	 * @deprecated As of 1.1.1, replaced by {@link
	 *             #getModelToIdentifierFunction()}
	 * @review
	 */
	@Deprecated
	public Function<T, S> getIdentifierFunction();

	/**
	 * Returns the relation's key.
	 *
	 * @return the relation's key
	 */
	public String getKey();

	/**
	 * Returns the function you can use to retrieve the related resource's
	 * identifier.
	 *
	 * @return the function that calculates the related resource's identifier
	 */
	public Function<T, S> getModelToIdentifierFunction();

}