/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.apio.architect.single.model;

import aQute.bnd.annotation.ProviderType;

import com.liferay.apio.architect.operation.Operation;

import java.util.List;

/**
 * Provides a wrapper for a model.
 *
 * @author Alejandro Hernández
 * @param  <T> the model's type
 */
@ProviderType
public interface SingleModel<T> {

	/**
	 * Returns the model.
	 *
	 * @return the model
	 */
	public T getModel();

	/**
	 * Returns the list of operations for the model.
	 *
	 * @return the list of operations
	 */
	public List<Operation> getOperations();

	/**
	 * Returns the resource's name.
	 *
	 * @return the resource's name
	 */
	public String getResourceName();

}