/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.apio.architect.supplier;

import aQute.bnd.annotation.ConsumerType;

/**
 * Defines a {@code java.util.function.Supplier} that can throw an exception.
 *
 * @author Alejandro Hernández
 * @param  <R> the type of the result of the supplier
 */
@ConsumerType
@FunctionalInterface
public interface ThrowableSupplier<R> {

	/**
	 * Returns a result of type {@code R} if the operation succeeds; otherwise
	 * throws an exception.
	 *
	 * @return a result of type {@code R} if the operation succeeds; an
	 *         exception otherwise
	 */
	public R get() throws Exception;

}